﻿using LMVCallbackLib;
using System;
using System.Collections.Generic;
using System.Drawing;
using System.Drawing.Imaging;
using System.Linq;
using System.Text;
using System.Windows.Forms;

namespace LEADTOOLS_Game_Capture_Demo
{
   class StillImageCallback : ILMVUserCallback
   {
      private bool _takeScreenShot = false;
      private int _screenShotCount = 1;
      private string _stillImageName = "";
      private ResultDialog _resultsDialog = new ResultDialog();
      public StillImageCallback() { }

      public bool TakeScreenShot
      {
         get { return _takeScreenShot; }
         set { _takeScreenShot = value; }
      }

      public string StillImageName
      {
         get { return _stillImageName; }
         set { _stillImageName = value; }
      }

      public void ReceiveProc(int pData, int lWidth, int lHeight, int lBitCount, int lSize, int bTopDown)
      {
         try
         {
            if (_takeScreenShot)
            {
               int stride = lWidth * lBitCount;  // bits per row
               stride += 31;            // round up to next 32-bit boundary
               stride /= 32;            // DWORDs per row
               stride *= 4;             // bytes per row

               using (Bitmap image = new Bitmap(lWidth, lHeight, stride, PixelFormat.Format32bppRgb, new IntPtr(pData)))
               {
                  if (bTopDown == 0)
                     image.RotateFlip(RotateFlipType.RotateNoneFlipY);

                  image.Save(string.Format(@"{0}-{1}.bmp", _stillImageName, _screenShotCount), ImageFormat.Bmp);
               }

               _screenShotCount++;
               _takeScreenShot = false;

               string fileName = string.Format(@"{0}\{1}-{2}.bmp", Application.StartupPath, _stillImageName, _screenShotCount);
               _resultsDialog.ShowDialog(null, "Screen shot saved to:\n" + fileName, Application.StartupPath, "Screenshot saved!");
            }
         }
         catch (Exception ex)
         {
            MessageBox.Show(ex.ToString());
         }
      }
   }
}
